@@ -8,12 +8,9 @@ from switchbot import SwitchbotLock
 def main():
     if len(sys.argv) < 3:
         print(f"Usage: {sys.argv[0]} <device_mac> <username> [<password>]")
-        exit(1)
+        sys.exit(1)
 
-    if len(sys.argv) == 3:
-        password = getpass.getpass()
-    else:
-        password = sys.argv[3]
+    password = getpass.getpass() if len(sys.argv) == 3 else sys.argv[3]
 
     try:
         result = SwitchbotLock.retrieve_encryption_key(
@@ -21,7 +18,7 @@ def main():
         )
     except RuntimeError as e:
         print(e)
-        exit(1)
+        sys.exit(1)
 
     print("Key ID: " + result["key_id"])
     print("Encryption key: " + result["encryption_key"])
