@@ -12,6 +12,9 @@ from .adv_parser import SwitchbotSupportedType, parse_advertisement_data
 from .const import (
     AirPurifierMode,
     FanMode,
+    HumidifierAction,
+    HumidifierMode,
+    HumidifierWaterLevel,
     LockStatus,
     SwitchbotAccountConnectionError,
     SwitchbotApiError,
@@ -32,7 +35,7 @@ from .devices.humidifier import SwitchbotHumidifier
 from .devices.light_strip import SwitchbotLightStrip
 from .devices.lock import SwitchbotLock
 from .devices.plug import SwitchbotPlugMini
-from .devices.relay_switch import SwitchbotRelaySwitch
+from .devices.relay_switch import SwitchbotRelaySwitch, SwitchbotRelaySwitch2PM
 from .devices.roller_shade import SwitchbotRollerShade
 from .devices.vacuum import SwitchbotVacuum
 from .discovery import GetSwitchbotDevices
@@ -43,6 +46,9 @@ __all__ = [
     "ColorMode",
     "FanMode",
     "GetSwitchbotDevices",
+    "HumidifierAction",
+    "HumidifierMode",
+    "HumidifierWaterLevel",
     "LockStatus",
     "SwitchBotAdvertisement",
     "Switchbot",
@@ -68,6 +74,7 @@ __all__ = [
     "SwitchbotPlugMini",
     "SwitchbotPlugMini",
     "SwitchbotRelaySwitch",
+    "SwitchbotRelaySwitch2PM",
     "SwitchbotRollerShade",
     "SwitchbotSupportedType",
     "SwitchbotSupportedType",
