@@ -13,6 +13,10 @@ class HumidifierMode(Enum):
     AUTO = 7
     DRYING_FILTER = 8
 
+    @classmethod
+    def get_modes(cls) -> list[str]:
+        return [mode.name.lower() for mode in cls]
+
 
 class HumidifierWaterLevel(Enum):
     EMPTY = 0
@@ -20,6 +24,16 @@ class HumidifierWaterLevel(Enum):
     MEDIUM = 2
     HIGH = 3
 
+    @classmethod
+    def get_levels(cls) -> list[str]:
+        return [level.name.lower() for level in cls]
+
+
+class HumidifierAction(Enum):
+    OFF = 0
+    HUMIDIFYING = 1
+    DRYING = 2
+
 
 OVER_HUMIDIFY_PROTECTION_MODES = {
     HumidifierMode.QUIET,
